summaryrefslogtreecommitdiffstats
path: root/src/collectionfieldsdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/collectionfieldsdialog.h
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/collectionfieldsdialog.h')
-rw-r--r--src/collectionfieldsdialog.h43
1 files changed, 22 insertions, 21 deletions
diff --git a/src/collectionfieldsdialog.h b/src/collectionfieldsdialog.h
index cad0492..7647bec 100644
--- a/src/collectionfieldsdialog.h
+++ b/src/collectionfieldsdialog.h
@@ -18,16 +18,16 @@ class KComboBox;
class KLineEdit;
class KPushButton;
-class QRadioButton;
-class QCheckBox;
-class QPainter;
+class TQRadioButton;
+class TQCheckBox;
+class TQPainter;
#include "datavectors.h"
#include "gui/listboxtext.h"
#include <kdialogbase.h>
-#include <qmap.h>
+#include <tqmap.h>
namespace Tellico {
namespace Data {
@@ -36,8 +36,8 @@ namespace Tellico {
class FieldListBox : public GUI::ListBoxText {
public:
- FieldListBox(QListBox* listbox, Data::FieldPtr field);
- FieldListBox(QListBox* listbox, Data::FieldPtr field, QListBoxItem* after);
+ FieldListBox(TQListBox* listbox, Data::FieldPtr field);
+ FieldListBox(TQListBox* listbox, Data::FieldPtr field, TQListBoxItem* after);
Data::FieldPtr field() const { return m_field; }
void setField(Data::FieldPtr field) { m_field = field; }
@@ -51,16 +51,17 @@ private:
*/
class CollectionFieldsDialog : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor sets up the dialog.
*
* @param coll A pointer to the collection parent of all the attributes
* @param parent A pointer to the parent widget
* @param name The widget name
*/
- CollectionFieldsDialog(Data::CollPtr coll, QWidget* parent, const char* name=0);
+ CollectionFieldsDialog(Data::CollPtr coll, TQWidget* tqparent, const char* name=0);
~CollectionFieldsDialog();
signals:
@@ -76,7 +77,7 @@ private slots:
void slotDelete();
void slotMoveUp();
void slotMoveDown();
- void slotTypeChanged(const QString& type);
+ void slotTypeChanged(const TQString& type);
void slotHighlightedChanged(int index);
void slotModified();
bool slotShowExtendedProperties();
@@ -85,10 +86,10 @@ private slots:
private:
void applyChanges();
void updateField();
- void updateTitle(const QString& title);
+ void updateTitle(const TQString& title);
bool checkValues();
- FieldListBox* findItem(const QListBox* box, Data::FieldPtr field);
- QStringList newTypesAllowed(int type);
+ FieldListBox* findItem(const TQListBox* box, Data::FieldPtr field);
+ TQStringList newTypesAllowed(int type);
Data::CollPtr m_coll;
Data::CollPtr m_defaultCollection;
@@ -100,7 +101,7 @@ private:
bool m_reordered;
int m_oldIndex;
- QListBox* m_fieldsBox;
+ TQListBox* m_fieldsBox;
KPushButton* m_btnNew;
KPushButton* m_btnDelete;
KPushButton* m_btnUp;
@@ -114,13 +115,13 @@ private:
KLineEdit* m_descEdit;
KPushButton* m_btnExtended;
- QRadioButton* m_formatNone;
- QRadioButton* m_formatPlain;
- QRadioButton* m_formatTitle;
- QRadioButton* m_formatName;
- QCheckBox* m_complete;
- QCheckBox* m_multiple;
- QCheckBox* m_grouped;
+ TQRadioButton* m_formatNone;
+ TQRadioButton* m_formatPlain;
+ TQRadioButton* m_formatTitle;
+ TQRadioButton* m_formatName;
+ TQCheckBox* m_complete;
+ TQCheckBox* m_multiple;
+ TQCheckBox* m_grouped;
};
} // end namespace
@@ -51,16 +51,17 @@ private:
* The constructor sets up the dialog.
*
- * @param coll A pointer to the collection parent of all the attributes
- * @param parent A pointer to the parent widget
+ * @param coll A pointer to the collection tqparent of all the attributes
+ * @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/